
-- CLEAR curse: clears the whole map -----------------------------------------

ID_CURSE_CLEAR=3

function clear_do_curse()
    utils_clear_map()
end

